=========
Reference
=========

Constants
=========

EquilibriumStatus
-----------------
.. autoclass:: poisson_approval.EquilibriumStatus
    :members:

Focus
-----
.. autoclass:: poisson_approval.Focus
    :members:

Containers
==========

Winners
-------
.. autoclass:: poisson_approval.Winners
    :members:

Scores
------
.. autoclass:: poisson_approval.Scores
    :members:

AnalyzedStrategies
------------------
.. autoclass:: poisson_approval.AnalyzedStrategies
    :members:

Events
======

Asymptotic
----------
.. autoclass:: poisson_approval.Asymptotic
    :members:

Event
-----
.. autoclass:: poisson_approval.Event
    :members:

EventDuo
--------
.. autoclass:: poisson_approval.EventDuo
    :members:

EventPivotStrict
----------------
.. autoclass:: poisson_approval.EventPivotStrict
    :members:

EventPivotTij
-------------
.. autoclass:: poisson_approval.EventPivotTij
    :members:

EventPivotTjk
-------------
.. autoclass:: poisson_approval.EventPivotTjk
    :members:

EventPivotWeak
--------------
.. autoclass:: poisson_approval.EventPivotWeak
    :members:

EventTrio
---------
.. autoclass:: poisson_approval.EventTrio
    :members:

EventTrio1t
-----------
.. autoclass:: poisson_approval.EventTrio1t
    :members:

EventTrio2t
-----------
.. autoclass:: poisson_approval.EventTrio2t
    :members:

Best Response
=============

.. autoclass:: poisson_approval.BestResponse
    :members:

Tau Vector
==========

.. autoclass:: poisson_approval.TauVector
    :members:

Strategies
==========

Strategy
--------
.. autoclass:: poisson_approval.Strategy
    :members:

StrategyTwelve
--------------
.. autoclass:: poisson_approval.StrategyTwelve
    :members:

StrategyThreshold
-----------------
.. autoclass:: poisson_approval.StrategyThreshold
    :members:

StrategyOrdinal
---------------
.. autoclass:: poisson_approval.StrategyOrdinal
    :members:

Profiles
========

Profile
-------
.. autoclass:: poisson_approval.Profile
    :members:

ProfileOrdinal
--------------
.. autoclass:: poisson_approval.ProfileOrdinal
    :members:

ProfileCardinal
---------------
.. autoclass:: poisson_approval.ProfileCardinal
    :members:

ProfileTwelve
-------------
.. autoclass:: poisson_approval.ProfileTwelve
    :members:

ProfileHistogram
----------------
.. autoclass:: poisson_approval.ProfileHistogram
    :members:

Grid exploration
================

ExploreGridProfilesOrdinal
--------------------------
.. autoclass:: poisson_approval.ExploreGridProfilesOrdinal
    :members:

ExploreGridTaus
---------------
.. autoclass:: poisson_approval.ExploreGridTaus
    :members:

Random Generators
=================

GeneratorProfileOrdinalUniform
------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalUniform
    :members:

GeneratorProfileOrdinalVariations
---------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalVariations
    :members:

GeneratorProfileHistogramUniform
--------------------------------
.. autoclass:: poisson_approval.GeneratorProfileHistogramUniform
    :members:

GeneratorTauVectorUniform
-------------------------
.. autoclass:: poisson_approval.GeneratorTauVectorUniform
    :members:

Meta-analysis
=============

NiceStatsProfileOrdinal
-----------------------
.. autoclass:: poisson_approval.NiceStatsProfileOrdinal
    :members:

Utils
=====

DictPrintingInOrder
-------------------
.. autoclass:: poisson_approval.DictPrintingInOrder
    :members:

DictPrintingInOrderIgnoringZeros
--------------------------------
.. autoclass:: poisson_approval.DictPrintingInOrderIgnoringZeros
    :members:

SetPrintingInOrder
------------------
.. autoclass:: poisson_approval.SetPrintingInOrder
    :members:

Util Module
-----------
.. automodule:: poisson_approval.utils.Util
    :members:

UtilCache Module
----------------
.. automodule:: poisson_approval.utils.UtilCache
    :members:

UtilMasks Module
----------------
.. automodule:: poisson_approval.utils.UtilMasks
    :members:
